@@ -10,7 +10,7 @@
 #include	"rfc822/rfc2047.h"
 #include	"rfc2045charset.h"
 #include	"rfc822/rfc822.h"
-#include	<unicode.h>
+#include	<courier-unicode.h>
 #include	<stdio.h>
 #include	<unistd.h>
 #include	<stdlib.h>
@@ -38,7 +38,7 @@ static void mksalutation_datefmt(const char *fmt_start,
 		fmt_end=fmt_start + strlen(fmt_start);
 	}
 
-	if ((t=rfc822_parsedt(date)))
+	if (rfc822_parsedate_chk(date, &t) == 0)
 	{
 		struct tm tmbuf;
 
@@ -275,7 +275,7 @@ static int reply_begin(size_t quote_level,
 		       void *arg)
 {
 	struct replyinfostruct *s=(struct replyinfostruct *)arg;
-	unicode_char quoteChar='>';
+	char32_t quoteChar='>';
 
 	/*
 	** Save quote level, begin conversion from unicode to the native
@@ -310,11 +310,11 @@ static int reply_begin(size_t quote_level,
 ** RFC 3676: (possibly partial) contents of a deflowed line, as unicode.
 */
 
-static int reply_contents(const unicode_char *txt,
+static int reply_contents(const char32_t *txt,
 			  size_t txt_size,
 			  void *arg)
 {
-	unicode_char spaceChar=' ';
+	char32_t spaceChar=' ';
 	size_t nonspc_cnt;
 
 	struct replyinfostruct *s=(struct replyinfostruct *)arg;
@@ -380,7 +380,7 @@ static int reply_contents(const unicode_char *txt,
 
 static int reply_end(void *arg)
 {
-	unicode_char newLine='\n';
+	char32_t newLine='\n';
 	struct replyinfostruct *s=(struct replyinfostruct *)arg;
 
 	unicode_convert_uc(s->u_handle, &newLine, 1);
@@ -394,7 +394,7 @@ static int reply_end(void *arg)
 */
 static int reply_wrap(void *arg)
 {
-	unicode_char spaceChar=' ';
+	char32_t spaceChar=' ';
 	struct replyinfostruct *s=(struct replyinfostruct *)arg;
 
 	/*
@@ -710,7 +710,7 @@ static int mkforward(struct rfc2045_mkreplyinfo *ri)
 	if (textplain_content)
 	{
 		/* Copy original headers. */
-		
+
 		hi=rfc2045header_start(ri->src, ri->rfc2045partp);
 		for (;;)
 		{
@@ -780,7 +780,7 @@ static int mkforward(struct rfc2045_mkreplyinfo *ri)
 				char *p=rfc2047_encode_str(ri->forwarddescr,
 							   ri->charset ?
 							   ri->charset
-							   : "iso-8859-1",
+							   : "utf-8",
 							   rfc2047_qp_allow_any
 							   );
 
@@ -795,7 +795,7 @@ static int mkforward(struct rfc2045_mkreplyinfo *ri)
 			rfc2045_mimepos(first_attachment, &start_pos, &end_pos,
 					&start_body,
 					&dummy, &dummy);
-			
+
 			if (SRC_SEEK(ri->src, start_pos) == (off_t)-1)
 			{
 				if (subject) free(subject);
@@ -819,7 +819,7 @@ static int mkforward(struct rfc2045_mkreplyinfo *ri)
 						&end_pos,
 						&start_body,
 						&dummy, &dummy);
-			
+
 				if (SRC_SEEK(ri->src, start_pos) == (off_t)-1)
 				{
 					if (subject) free(subject);
@@ -1525,7 +1525,7 @@ static void copyheaders(struct rfc2045_mkreplyinfo *ri)
 	char	*header, *value;
 
 
-	writes(ri, "\nContent-Type: text/rfc822-headers; charset=\"iso-8859-1\"\n"
+	writes(ri, "\nContent-Type: text/rfc822-headers; charset=\"utf-8\"\n"
 	       "Content-Disposition: attachment\n"
 	       "Content-Transfer-Encoding: 8bit\n\n"
 	       );
